@@ -12,7 +12,7 @@ use std::net::IpAddr;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct OpenVpn {
     pid: u32,
     pub openvpn_dns: Option<IpAddr>,
